componenttools.partition_components_by_durations_ge
===================================================

.. autofunction:: abjad.tools.componenttools.partition_components_by_durations_ge.partition_components_by_durations_ge
